{% extends "base.html" %}

{% block title %}
    Home
{% endblock %}

{% block content %}
    <div class="doublebox">
        <div class="top">
            <span class="left">Under construction</span>
        </div>
        <div class="bot">
            Non c'è ancora niente qui. O quasi. C'è solo la <a href="{{ url_for("wikiview.wikiview_index") }}">wiki</a> in sola lettura...
        </div>
    </div>
{% endblock %}