{% extends "base.html" %}

{% block title %}
    {{ page.title }} - RYGwiki
{% endblock %}

{% block content %}
    <div class="doublebox">
        <div class="top">
            <span class="left">
                Wiki page
            </span>
            <span class="right">
                <a class="permalink no-icon" href="{{ url_for("wikiview.wikiview_by_id", page_id=page.page_id|string) }}">#</a>
            </span>
        </div>
        <div class="bot">
            <h1>
                {{ page.title }}
            </h1>
            <div>
                {{ parsed_content }}
            </div>
        </div>
    </div>
{% endblock %}
