{% extends "base.html" %}

{% block title %}
    Indice RYGwiki
{% endblock %}

{% block content %}
    <div class="doublebox">
        <div class="top">
            <span class="left">
                Wiki Index
            </span>
        </div>
        <div class="bot">
            <ul>
                {% for page in pages %}
                    <li><a href="{{ url_for("wikiview.wikiview_by_id", page_id=page.page_id|string) }}">{{ page.title }}</a></li>
                {% endfor %}
            </ul>
        </div>
    </div>
{% endblock %}
