body {
  font-family: "Arial", "Helvetica Neue", sans-serif;
  background-color: #0d193b;
  color: #a0ccff;
  box-sizing: border-box;
}
a {
  color: #00caca;
  text-decoration: none;
}
a:hover {
  color: #4affff;
}
a:active {
  color: white;
}
a:not(.no-icon)::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f0c1";
  margin-right: 4px;
}
a:not(.no-icon)[href^="https://t.me"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f2c6";
  margin-right: 3px;
}
a:not(.no-icon)[href^="https://www.youtube.com"]::before,
a:not(.no-icon)[href^="https://youtu.be"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f167";
  margin-right: 3px;
}
a:not(.no-icon)[href^="https://vimeo.com"]::before,
a:not(.no-icon)[href^="https://player.vimeo.com"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f27d";
  margin-right: 4px;
}
a:not(.no-icon)[href^="https://github.com"]::before,
a:not(.no-icon)[href^="https://gist.github.com"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f09b";
  margin-right: 4px;
}
a:not(.no-icon)[href^="https://itch.io"]::before,
a:not(.no-icon)[href^="https://steffo.itch.io"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f83a";
  margin-right: 3px;
}
a:not(.no-icon)[href^="https://www.kickstarter.com"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f3bb";
  margin-right: 4px;
}
a:not(.no-icon)[href^="https://reddit.com"]::before,
a:not(.no-icon)[href^="https://new.reddit.com"]::before,
a:not(.no-icon)[href^="https://old.reddit.com"]::before,
a:not(.no-icon)[href^="https://redd.it"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f281";
  margin-right: 3px;
}
a:not(.no-icon)[href^="https://www.twitch.tv"]::before,
a:not(.no-icon)[href^="https://clips.twitch.tv"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f1e8";
  margin-right: 4px;
}
a:not(.no-icon)[href^="https://store.steampowered.com"]::before,
a:not(.no-icon)[href^="https://steamcommunity.com"]::before,
a:not(.no-icon)[href^="https://partner.steamgames.com"]::before,
a:not(.no-icon)[href^="steam:"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f1b6";
  margin-right: 4px;
}
a:not(.no-icon)[href^="https://twitter.com"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f099";
  margin-right: 3px;
}
a:not(.no-icon)[href^="https://it.wikipedia.org"]::before,
a:not(.no-icon)[href^="https://en.wikipedia.org"]::before {
  font-family: "Font Awesome 5 Brands";
  font-weight: bold;
  content: "\f266";
  margin-right: 3px;
}
a:not(.no-icon)[href^="#"]::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f13d";
  margin-right: 3px;
}
a:not(.no-icon)[href^="http:"]::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f09c";
  margin-right: 4px;
}
a:not(.no-icon)[href^="magnet:"]::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f076";
  margin-right: 4px;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  color: #ffffff;
  margin-top: 0;
  margin-bottom: 0;
  font-weight: normal;
}
code {
  font-family: "Consolas", "Source Code Pro", monospace;
}
blockquote {
  color: #a0ccff;
  border-left: 3px solid #a0ccff;
  background-color: rgba(160, 204, 255, 0.1);
  padding: 2px 4px 2px 8px;
  margin: 8px;
}
textarea {
  background-color: rgba(160, 204, 255, 0.1);
  color: #a0ccff;
  border: 1px solid #a0ccff;
  padding: 2px;
  margin: 1px;
  font-size: small;
  font-family: "Consolas", "Source Code Pro", monospace;
  width: 100%;
  height: 300px;
}
button,
input[type="submit"],
.btn {
  background-color: rgba(160, 204, 255, 0.1);
  color: #a0ccff !important;
  border: 1px solid #a0ccff;
  border-radius: 0;
  padding: 2px 8px;
  margin: 1px;
  font-size: medium;
  font-family: sans-serif;
  text-decoration: none;
  cursor: default;
}
button:hover,
input[type="submit"]:hover,
.btn:hover {
  background-color: rgba(160, 204, 255, 0.2);
  color: #ffffff;
  border-color: #ffffff;
}
button:active,
input[type="submit"]:active,
.btn:active {
  background-color: rgba(160, 204, 255, 0.3);
  color: white;
  border-color: white;
}
pre {
  margin: 0;
}
img {
  margin-left: auto;
  margin-right: auto;
  display: block;
  max-width: 100%;
}
nav {
  display: flex;
  justify-content: space-between;
  height: 50px;
  line-height: 50px;
}
nav .nav-left {
  text-align: left;
}
nav .nav-center {
  text-align: center;
}
nav .nav-right {
  text-align: right;
}
nav .nav-image {
  height: 50px;
  display: inline;
  vertical-align: middle;
}
nav .nav-sitename {
  color: #ffffff;
  font-weight: bold;
}
nav .nav-login-unavailable {
  opacity: 0.25;
}
.h-container {
  display: flex;
  justify-content: center;
  align-content: center;
  flex-direction: column;
}
@media (min-width: 800px) {
  .h-container {
    flex-direction: row;
  }
}
.main-container {
  width: 100%;
}
@media (min-width: 800px) {
  .main-container {
    width: 800px;
  }
}
@media (min-width: 1200px) {
  .main-container {
    width: 1200px;
  }
}
.box {
  background-color: rgba(160, 204, 255, 0.1);
  border-radius: 4px;
  padding: 8px;
  margin: 8px;
}
.doublebox {
  margin: 8px;
}
.doublebox .top {
  display: flex;
  justify-content: space-between;
  background-color: rgba(160, 204, 255, 0.2);
  padding: 4px;
  border-radius: 4px 4px 0 0;
  color: #ffffff;
  font-size: smaller;
  font-weight: bold;
  height: 16px;
}
.doublebox .top .left {
  align-self: flex-start;
}
.doublebox .top .right {
  align-self: flex-end;
}
.doublebox .bot {
  background-color: rgba(160, 204, 255, 0.1);
  padding: 8px;
  border-radius: 0 0 4px 4px;
}
.multirow {
  list-style-type: none;
  margin-top: 0;
  margin-bottom: 0;
  padding-left: 0;
}
.palette-color {
  border-radius: 4px;
  width: 32px;
  height: 32px;
  display: inline-block;
}
.palette-color.light {
  border: 1px solid black;
}
.palette-color.dark {
  border: 1px solid white;
}
.proscons {
  padding: 4px 4px 4px 8px;
  margin: 4px;
  border-radius: 4px;
}
.proscons.plus {
  color: #7dff7d;
  background-color: rgba(125, 255, 125, 0.1);
}
.proscons.plus::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f0fe";
  margin-right: 6px;
}
.proscons.minus {
  color: #ff7d7d;
  background-color: rgba(255, 125, 125, 0.1);
}
.proscons.minus::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f146";
  margin-right: 6px;
}
.proscons.stars {
  background-color: rgba(255, 255, 125, 0.1);
  color: #ffff7d;
  display: flex;
}
.proscons.stars .stars-0 {
  margin-right: 6px;
}
.proscons.stars .stars-0::after {
  font-family: "Font Awesome 5 Free";
  font-weight: normal;
  content: "\f005\f005\f005\f005\f005";
}
.proscons.stars .stars-1 {
  margin-right: 6px;
}
.proscons.stars .stars-1::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f005";
}
.proscons.stars .stars-1::after {
  font-family: "Font Awesome 5 Free";
  font-weight: normal;
  content: "\f005\f005\f005\f005";
}
.proscons.stars .stars-2 {
  margin-right: 6px;
}
.proscons.stars .stars-2::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f005\f005";
}
.proscons.stars .stars-2::after {
  font-family: "Font Awesome 5 Free";
  font-weight: normal;
  content: "\f005\f005\f005";
}
.proscons.stars .stars-3 {
  margin-right: 6px;
}
.proscons.stars .stars-3::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f005\f005\f005";
}
.proscons.stars .stars-3::after {
  font-family: "Font Awesome 5 Free";
  font-weight: normal;
  content: "\f005\f005";
}
.proscons.stars .stars-4 {
  margin-right: 6px;
}
.proscons.stars .stars-4::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f005\f005\f005\f005";
}
.proscons.stars .stars-4::after {
  font-family: "Font Awesome 5 Free";
  font-weight: normal;
  content: "\f005";
}
.proscons.stars .stars-5 {
  margin-right: 6px;
}
.proscons.stars .stars-5::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f005\f005\f005\f005\f005";
}
.proscons:not(.plus):not(.minus):not(.stars) {
  color: #a0ccff;
  background-color: rgba(160, 204, 255, 0.1);
}
.proscons:not(.plus):not(.minus):not(.stars)::before {
  font-family: "Font Awesome 5 Free";
  font-weight: bold;
  content: "\f0c8";
  margin-right: 6px;
}
.proscons.big {
  font-size: xx-large;
}
.spoiler {
  color: rgba(0, 0, 0, 0);
  border: 1px solid rgba(160, 204, 255, 0.1);
  border-radius: 2px;
}
.spoiler:hover {
  color: #a0ccff;
}
.faded {
  opacity: 0.3;
}
/*# sourceMappingURL=styling.css.map */