from .helloworld import bp as helloworld
from .testing import bp as testing
from .home import bp as home
from .wikiview import bp as wikiview
from .tglogin import bp as tglogin

__all__ = ["helloworld", "testing", "home", "wikiview", "tglogin"]
